import { OnInit, OnChanges, SimpleChanges, ElementRef, EventEmitter } from '@angular/core';
import { service as PBIService, IEmbedConfiguration, Embed, models } from 'powerbi-client';
export declare class PowerBIComponentComponent implements OnInit, OnChanges {
    powerBIService: PBIService.Service;
    component: Embed;
    accessToken: string;
    tokenType: string;
    embedUrl: string;
    type: string;
    id: string;
    embedded: EventEmitter<number>;
    powerbiFrame: ElementRef;
    constructor(powerBIService: PBIService.Service);
    ngOnInit(): void;
    ngOnChanges(changes: SimpleChanges): void;
    /**
     * Validates if needed accessToken and embedUrl aren't empty and are strings
     * @param {string} accessToken - access token to embed component, obtained through pbi rest api
     * @param {string} embedUrl - url obtained through pbi rest api or pbi app
     * @return {boolean}
     */
    validateOptions(accessToken: string, embedUrl: string): boolean;
    /**
     * Get the token type class or enum from string ('Embed' or 'Aad')
     * @param {string} tokenType - token type class name in string it must be 'Embed' or 'Aad'
     * @return {models.TokenType}
     */
    getTokenType(tokenType: string): models.TokenType;
    /**
     * Executes an embeding operation with pbi client library
     * and assign the embed component to a property
     * @param {HTMLEelement} element - native element to embed pbi dashboard, report, or whatever
     * @param {IEmbedConfiguration} config - configuration to embed
     * @param {string} config.accessToken - access token to embed component, obtained through pbi rest api
     * @param {string} config.tokenType - type of accessToken, the most common is TokenType.Embed
     * @param {string} config.embedUrl - url obtained through pbi rest api or pbi app
     * @param {string} config.type - type of embedded component, like 'report' or 'dashboard'
     * @param {string} config.id - component/element id like '5dac7a4a-4452-46b3-99f6-a25915e0fe55'
     */
    embed(element: HTMLElement, config: IEmbedConfiguration): void;
    /**
     * Reset the component to delete the last embedded component
     * @param {HTMLElement} element - native element where the embedded was made
     */
    reset(element: HTMLElement): void;
}
